Público em Geral / Nota Fiscal Eletrônica / Consulta Completa da NFC-e

CONSULTA DA NFC-e
| SIM REDE DE POSTOS LTDA
CNPJ: 07.473.735/0064-65 Inscrição Estadual: 3820019776
BR 386 km 435, 2555, Centro, Nova Santa Rita, RS
DANFE NFC-e - Documento Auxiliar da Nota Fiscal Eletrônica para Consumidor Final - Via Consumidor
NFC-e não permite aproveitamento de crédito de ICMS
Emissão normal
NFC-e nº: 957106 Série: 2 Data de Emissão: 28/09/2019 19:04:22
Consulte pela Chave de Acesso em https://www.sefaz.rs.gov.br/NFCE
CHAVE DE ACESSO
4319 0907 4737 3500 6465 6500 2000 9571 0618 8374 8395
Protocolo de Autorização: 143191332381420
CONSUMIDOR
CPF: 044.272.479-97
Código | Descrição | Qtde | Un | Vl Unit | Vl Total
2383 | GASOLINA ADITIVADA Bico 12 | 31,69 | L | 4,599 | 145,74
Valor total R$ | 145,74
Valor descontos R$ | 0,00
FORMA PAGAMENTO | VALOR PAGO R$
| NaN
Versão XSLT: 1.10

Administração Tributária: | Receita Estadual RS
Data/Hora da Consulta: | 11/08/2020 12:32:42